lcvtoolbox.vision.encoding
==========================

.. automodule:: lcvtoolbox.vision.encoding
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree: .
      :nosignatures:
   
      decode_bytes_to_image
      decode_mask_from_bytes
      decode_mask_from_string
      decode_string_to_image
      encode_image_adaptive
      encode_image_lossless
      encode_image_lossy
      encode_image_to_bytes
      encode_image_to_string
      encode_mask_batch
      encode_mask_efficient
      encode_mask_to_bytes
      encode_mask_to_string
      get_mask_encoding_stats
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree: .
      :nosignatures:
      :template: custom-class-template.rst
   
      CompressionPreset
      ImageFormat
      MaskFormat
   
   

   
   
   



.. rubric:: Modules

.. autosummary::
   :toctree: .
   :template: custom-module-template.rst
   :recursive:

   binary_mask
   file
   image
   numpy
   rle

